@@ -55,7 +55,11 @@
 
 #include <goffice/app/io-context.h>
 #include <goffice/app/error-info.h>
+#include <goffice/utils/go-format.h>
+#include <goffice/utils/go-glib-extras.h>
+
 #include <gsf/gsf-input-textline.h>
+
 #include <string.h>
 #include <stdlib.h>
 
@@ -76,7 +80,7 @@ typedef struct {
 	GSList *sheet_order;
 	GSList *std_names, *real_names;
 
-	GnmExprConventions *exprconv;
+	GnmConventions *convs;
 } ApplixReadState;
 
 /* #define NO_DEBUG_APPLIX */
@@ -234,7 +238,7 @@ applix_sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb)
 
 static char const *
 applix_rangeref_parse (GnmRangeRef *res, char const *start, GnmParsePos const *pp,
-		       GnmExprConventions const *convention)
+		       GnmConventions const *convention)
 {
 	char const *ptr = start, *tmp1, *tmp2;
 	Workbook *wb = pp->wb;
@@ -581,7 +585,7 @@ applix_parse_style (ApplixReadState *state, unsigned char **buffer)
 					break;
 				}
 				case 'G' : /* general */
-					gnm_style_set_format_text (style, "General");
+					gnm_style_set_format (style, go_format_general ());
 
 					/* What is 'Gf' ? */
 					if (sep[1] == 'f')
@@ -1168,7 +1172,7 @@ applix_read_cells (ApplixReadState *state)
 					texpr = gnm_expr_parse_str (expr_string+1,
 						parse_pos_init_cell (&pos, cell),
 								   GNM_EXPR_PARSE_DEFAULT,
-								   state->exprconv,
+								   state->convs,
 								   parse_error_init (&perr));
 
 				if (texpr == NULL) {
@@ -1346,7 +1350,7 @@ applix_read_absolute_name (ApplixReadState *state, char *buffer)
 		return TRUE;
 	applix_rangeref_parse (&ref, end+2,
 		parse_pos_init (&pp, state->wb, NULL, 0, 0),
-		state->exprconv);
+		state->convs);
 	ref.a.col_relative = ref.b.col_relative =
 		ref.a.row_relative = ref.b.row_relative = FALSE;
 
@@ -1544,57 +1548,55 @@ cb_remove_style (gpointer key, gpointer value, gpointer user_data)
 	return TRUE;
 }
 
-static struct {
-	char const *applixname;
-	char const *gnumericname;
-} const simple_renames[] = {
-	{ "IPAYMT", "IPMT" },
-	{ "PAYMT", "PMT" },
-	{ "PPAYMT", "PPMT" },
-	{ NULL, NULL }
-};
-
 static GnmExpr const *
-function_renamer (char const *name,
-		  GnmExprList *args,
-		  GnmExprConventions *convs)
+applix_func_map_in (GnmConventions const *conv, Workbook *scope,
+		    char const *name, GnmExprList *args)
 {
-	Workbook *wb = NULL;
+	static struct {
+		char const *applix_name;
+		char const *gnm_name;
+	} const sc_func_renames[] = {
+		{ "IPAYMT",	"IPMT" },
+		{ "PAYMT",	"PMT" },
+		{ "PPAYMT",	"PPMT" },
+		{ NULL, NULL }
+	};
+	static GHashTable *namemap = NULL;
+
+	GnmFunc  *f;
+	char const *new_name;
 	int i;
-	GnmFunc *f;
 
-	for (i = 0; simple_renames[i].applixname; i++)
-		if (strcmp (name, simple_renames[i].applixname) == 0) {
-			name = simple_renames[i].gnumericname;
-			break;
-		}
+	if (NULL == namemap) {
+		namemap = g_hash_table_new (go_ascii_strcase_hash, 
+					    go_ascii_strcase_equal);
+		for (i = 0; sc_func_renames[i].applix_name; i++)
+			g_hash_table_insert (namemap,
+				(gchar *) sc_func_renames[i].applix_name,
+				(gchar *) sc_func_renames[i].gnm_name);
+	}
 
-	f = gnm_func_lookup (name, wb);
-	if (f)
-		return gnm_expr_new_funcall (f, args);
-
-	return gnm_func_placeholder_factory (name, args, convs);
+	if (NULL != namemap &&
+	    NULL != (new_name = g_hash_table_lookup (namemap, name)))
+		name = new_name;
+	if (NULL == (f = gnm_func_lookup (name, scope)))
+		f = gnm_func_add_placeholder (scope, name, "", TRUE);
+	return gnm_expr_new_funcall (f, args);
 }
 
-static GnmExprConventions *
-applix_conventions (void)
+static GnmConventions *
+applix_conventions_new (void)
 {
-	GnmExprConventions *res = gnm_expr_conventions_new ();
+	GnmConventions *conv = gnm_conventions_new ();
 
-	res->intersection_char = 0;
-	res->accept_hash_logicals = TRUE;
-	res->allow_absolute_sheet_references = TRUE;
-	res->range_sep_dotdot = TRUE;
-	res->unknown_function_handler = gnm_func_placeholder_factory;
-	res->ref_parser = applix_rangeref_parse;
+	conv->intersection_char		= 0;
+	conv->accept_hash_logicals	= TRUE;
+	conv->allow_absolute_sheet_references = TRUE;
+	conv->range_sep_dotdot		= TRUE;
+	conv->input.range_ref		= applix_rangeref_parse;
+	conv->input.func		= applix_func_map_in;
 
-	res->function_rewriter_hash =
-		g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_insert (res->function_rewriter_hash,
-			     (gchar *)"IPAYMT",
-			     function_renamer);
-
-	return res;
+	return conv;
 }
 
 void
@@ -1621,7 +1623,7 @@ applix_read (IOContext *io_context, WorkbookView *wb_view, GsfInput *src)
 	state.sheet_order = NULL;
 	state.std_names   = NULL;
 	state.real_names  = NULL;
-	state.exprconv    = applix_conventions ();
+	state.convs       = applix_conventions_new ();
 
 	/* Actually read the workbook */
 	res = applix_read_impl (&state);
@@ -1669,5 +1671,5 @@ applix_read (IOContext *io_context, WorkbookView *wb_view, GsfInput *src)
 	if (state.parse_error != NULL)
 		gnumeric_io_error_info_set (io_context, state.parse_error);
 
-	gnm_expr_conventions_free (state.exprconv);
+	gnm_conventions_free (state.convs);
 }
