@@ -47,7 +47,7 @@
 GNM_PLUGIN_MODULE_HEADER;
 
 #define DAY_SECONDS (3600*24)
-#define DATE_CONV(ep)		workbook_date_conv (ep->sheet->workbook)
+#define DATE_CONV(ep)		workbook_date_conv ((ep)->sheet->workbook)
 
 static GnmValue *
 make_date (GnmValue *res)
@@ -119,7 +119,7 @@ static GnmFuncHelp const help_date[] = {
 };
 
 static GnmValue *
-gnumeric_date (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_date (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float year  = value_get_as_float (argv [0]);
 	gnm_float month = value_get_as_float (argv [1]);
@@ -193,7 +193,7 @@ static GnmFuncHelp const help_unix2date[] = {
 };
 
 static GnmValue *
-gnumeric_unix2date (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_unix2date (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float futime = value_get_as_float (argv [0]);
 	time_t     utime  = (time_t)futime;
@@ -229,7 +229,7 @@ static GnmFuncHelp const help_date2unix[] = {
 };
 
 static GnmValue *
-gnumeric_date2unix (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_date2unix (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float fserial = value_get_as_float (argv [0]);
 	int        serial  = (int)fserial;
@@ -266,7 +266,7 @@ static GnmFuncHelp const help_datevalue[] = {
 };
 
 static GnmValue *
-gnumeric_datevalue (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_datevalue (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return value_new_int (datetime_value_to_serial (argv[0], DATE_CONV (ei->pos)));
 }
@@ -388,7 +388,7 @@ datedif_opt_md (GDate *gdate1, GDate *gdate2, gboolean excel_compat)
 }
 
 static GnmValue *
-gnumeric_datedif (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_datedif (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int date1, date2;
 	char const *opt;
@@ -449,7 +449,7 @@ static GnmFuncHelp const help_edate[] = {
 };
 
 static GnmValue *
-gnumeric_edate (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_edate (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GODateConventions const *conv = DATE_CONV (ei->pos);
 	gnm_float serial = value_get_as_float (argv[0]);
@@ -499,7 +499,7 @@ static GnmFuncHelp const help_today[] = {
 };
 
 static GnmValue *
-gnumeric_today (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_today (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return make_date (value_new_int (datetime_timet_to_serial (time (NULL), DATE_CONV (ei->pos))));
 }
@@ -533,7 +533,7 @@ static GnmFuncHelp const help_now[] = {
 };
 
 static GnmValue *
-gnumeric_now (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_now (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return value_new_float (datetime_timet_to_serial_raw (time (NULL), DATE_CONV (ei->pos)));
 }
@@ -558,7 +558,7 @@ static GnmFuncHelp const help_time[] = {
 };
 
 static GnmValue *
-gnumeric_time (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_time (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float hours, minutes, seconds;
 
@@ -592,7 +592,7 @@ static GnmFuncHelp const help_timevalue[] = {
 };
 
 static GnmValue *
-gnumeric_timevalue (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_timevalue (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float raw = datetime_value_to_serial_raw (argv[0], DATE_CONV (ei->pos));
 	return value_new_float (raw - (int)raw);
@@ -623,7 +623,7 @@ static GnmFuncHelp const help_hour[] = {
 };
 
 static GnmValue *
-gnumeric_hour (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_hour (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -660,7 +660,7 @@ static GnmFuncHelp const help_minute[] = {
 };
 
 static GnmValue *
-gnumeric_minute (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_minute (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -697,7 +697,7 @@ static GnmFuncHelp const help_second[] = {
 };
 
 static GnmValue *
-gnumeric_second (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_second (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float d = value_get_as_float (argv[0]);
 
@@ -733,7 +733,7 @@ static GnmFuncHelp const help_year[] = {
 };
 
 static GnmValue *
-gnumeric_year (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_year (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1900;
 	GDate date;
@@ -767,7 +767,7 @@ static GnmFuncHelp const help_month[] = {
 };
 
 static GnmValue *
-gnumeric_month (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_month (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1;
 	GDate date;
@@ -801,7 +801,7 @@ static GnmFuncHelp const help_day[] = {
 };
 
 static GnmValue *
-gnumeric_day (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_day (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int res = 1;
 	GDate date;
@@ -842,7 +842,7 @@ static GnmFuncHelp const help_weekday[] = {
 };
 
 static GnmValue *
-gnumeric_weekday (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_weekday (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	int res;
@@ -901,7 +901,7 @@ static GnmFuncHelp const help_days360[] = {
 };
 
 static GnmValue *
-gnumeric_days360 (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_days360 (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	basis_t basis;
 	GDate date1, date2;
@@ -946,7 +946,7 @@ static GnmFuncHelp const help_eomonth[] = {
 };
 
 static GnmValue *
-gnumeric_eomonth (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_eomonth (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float months = argv[1] ? value_get_as_float (argv[1]) : 0;
 	GDate date;
@@ -1001,7 +1001,7 @@ static GnmFuncHelp const help_workday[] = {
 };
 
 static gint
-float_compare (const gnm_float *a, const gnm_float *b)
+float_compare (gnm_float const *a, gnm_float const *b)
 {
         if (*a < *b)
                 return -1;
@@ -1012,7 +1012,7 @@ float_compare (const gnm_float *a, const gnm_float *b)
 }
 
 static GnmValue *
-gnumeric_workday (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_workday (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	GODateConventions const *conv = DATE_CONV (ei->pos);
@@ -1196,41 +1196,38 @@ get_serial_weekday (int serial, int *offset, GODateConventions const *conv)
 	return serial;
 }
 
-typedef struct
-{
+typedef struct {
 	int start_serial, end_serial;
 	int res;
 } networkdays_holiday_closure;
 
 static GnmValue *
-networkdays_holiday_callback (GnmValue const *v, GnmEvalPos const *ep,
-			      int x, int y, void *user_data)
+cb_networkdays_holiday (GnmValueIter const *v_iter,
+			networkdays_holiday_closure *close)
 {
-	networkdays_holiday_closure * close =
-	    (networkdays_holiday_closure *)user_data;
 	int serial;
 	GDate date;
-	GODateConventions const *conv = DATE_CONV (ep);
+	GODateConventions const *conv = DATE_CONV (v_iter->ep);
 
-	if (VALUE_IS_ERROR (v))
-		return value_dup (v);
-	serial = datetime_value_to_serial (v, conv);
+	if (VALUE_IS_ERROR (v_iter->v))
+		return value_dup (v_iter->v);
+	serial = datetime_value_to_serial (v_iter->v, conv);
         if (serial <= 0)
-		return value_new_error_NUM (ep);
+		return value_new_error_NUM (v_iter->ep);
 
 	if (serial < close->start_serial || close->end_serial < serial)
 		return NULL;
 
 	datetime_serial_to_g (&date, serial, conv);
         if (!g_date_valid (&date))
-		return value_new_error_NUM (ep);
+		return value_new_error_NUM (v_iter->ep);
 	if (g_date_get_weekday (&date) < G_DATE_SATURDAY)
 		++close->res;
 	return NULL;
 }
 
 static GnmValue *
-gnumeric_networkdays (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_networkdays (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	int start_serial;
 	int end_serial;
@@ -1264,10 +1261,8 @@ gnumeric_networkdays (FunctionEvalInfo *ei, GnmValue const * const *argv)
 	res -= ((res/7)*2);	/* Remove weekends */
 
 	if (argv[2] != NULL)
-		value_area_foreach (argv[2], ei->pos,
-				    CELL_ITER_IGNORE_BLANK,
-				    &networkdays_holiday_callback,
-				    &close);
+		value_area_foreach (argv[2], ei->pos, CELL_ITER_IGNORE_BLANK,
+			(GnmValueIterFunc) &cb_networkdays_holiday, &close);
 
 	res = res - start_offset + end_offset - close.res;
 
@@ -1304,7 +1299,7 @@ static GnmFuncHelp const help_isoweeknum[] = {
 };
 
 static GnmValue *
-gnumeric_isoweeknum (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_isoweeknum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	datetime_value_to_g (&date, argv[0], DATE_CONV (ei->pos));
@@ -1342,7 +1337,7 @@ static GnmFuncHelp const help_isoyear[] = {
 };
 
 static GnmValue *
-gnumeric_isoyear (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_isoyear (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	int year;
@@ -1395,7 +1390,7 @@ static GnmFuncHelp const help_weeknum[] = {
 };
 
 static GnmValue *
-gnumeric_weeknum (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_weeknum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GDate date;
 	gnm_float method = argv[1] ? gnm_floor (value_get_as_float (argv[1])) : 1;
@@ -1431,7 +1426,7 @@ static GnmFuncHelp const help_yearfrac[] = {
 };
 
 static GnmValue *
-gnumeric_yearfrac (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_yearfrac (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	GODateConventions const *conv = DATE_CONV (ei->pos);
 	GDate start_date, end_date;
