@@ -28,7 +28,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include <string.h>
 #include "html.h"
@@ -52,9 +52,9 @@
 #include <libxml/HTMLparser.h>
 #include <libxml/HTMLtree.h>
 
-#define CC2XML(s) ((const xmlChar *)(s))
+#define CC2XML(s) ((xmlChar const *)(s))
 #define C2XML(s) ((xmlChar *)(s))
-#define CXML2C(s) ((const char *)(s))
+#define CXML2C(s) ((char const *)(s))
 #define XML2C(s) ((char *)(s))
 
 typedef struct {
@@ -170,7 +170,7 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 			/* Check whether we need to skip merges from above */
 			pos.row = tc->row;
 			pos.col = col + 1;
-			while (sheet_merge_contains_pos (tc->sheet, &pos)) {
+			while (gnm_sheet_merge_contains_pos (tc->sheet, &pos)) {
 				col++;
 				pos.col++;
 			}
@@ -247,7 +247,7 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 			if (buf->len > 0) {
 				GnmCell *cell = sheet_cell_fetch (tc->sheet, col + 1, tc->row);
 				sheet_style_set_pos (tc->sheet, col + 1, tc->row, mstyle);
-				cell_set_text (cell, buf->str);
+				gnm_cell_set_text (cell, buf->str);
 			} else
 				gnm_style_unref (mstyle);
 
@@ -267,7 +267,7 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 				GnmRange *r = &range;
 
 				range_init (r, col + 1, tc->row, col + colspan, tc->row + rowspan - 1);
-				sheet_merge_add (tc->sheet, r, FALSE, NULL);
+				gnm_sheet_merge_add (tc->sheet, r, FALSE, NULL);
 			}
 
 			col += colspan;
@@ -332,7 +332,7 @@ html_read_table (htmlNodePtr cur, htmlDocPtr doc, WorkbookView *wb_view,
 }
 
 /* Element types which imply that we are inside a table */
-static const char *table_start_elt_types[] = {
+static char const *table_start_elt_types[] = {
 	"caption",
 	"col",
 	"colgroup",
@@ -344,23 +344,23 @@ static const char *table_start_elt_types[] = {
 };
 
 /* Element types which imply that we are inside a row */
-static const char *row_start_elt_types[] = {
+static char const *row_start_elt_types[] = {
 	"td",
 	"th",
 	NULL
 };
 
 /* Element types which occur inside tables and rows, but also outside */
-static const char *cont_elt_types[] = {
+static char const *cont_elt_types[] = {
 	"del",
 	"ins",
 	NULL
 };
 
 static gboolean 
-is_elt_type (htmlNodePtr ptr, const char** types)
+is_elt_type (htmlNodePtr ptr, char const ** types)
 {
-	const char **p;
+	char const **p;
 	gboolean ret = FALSE;
 
 	for (p = types; *p; p++)
@@ -518,7 +518,7 @@ html_file_open (GOFileOpener const *fo, IOContext *io_context,
 				bomlen = 0;
 			}
 			ctxt = htmlCreatePushParserCtxt (
-				NULL, NULL, (const char *)(buf + bomlen),
+				NULL, NULL, (char const *)(buf + bomlen),
 				4 - bomlen, gsf_input_name (input), enc);
 			
 			for (; size > 0 ; size -= len) {
@@ -527,10 +527,10 @@ html_file_open (GOFileOpener const *fo, IOContext *io_context,
 				if (buf == NULL)
 					break;
 				htmlParseChunk (
-					ctxt, (const char *)buf, len, 0);
+					ctxt, (char const *)buf, len, 0);
 			}
 
-			htmlParseChunk (ctxt, (const char *)buf, 0, 1);
+			htmlParseChunk (ctxt, (char const *)buf, 0, 1);
 			doc = ctxt->myDoc;
 			htmlFreeParserCtxt (ctxt);
 		}
