@@ -21,16 +21,14 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialog-stf.h"
 #include <gnm-format.h>
 #include <workbook.h>
 #include <gui-util.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 /*************************************************************************************************
  * MISC UTILITY FUNCTIONS
@@ -87,11 +85,33 @@ format_page_trim_menu_changed (G_GNUC_UNUSED GtkMenu *menu,
 	format_page_update_preview (data);
 }
 
+/*
+ * More or less a copy of gtk_tree_view_clamp_column_visible.
+ */
+static void
+tree_view_clamp_column_visible (GtkTreeView       *tree_view,
+				GtkTreeViewColumn *column)
+{
+	GtkAdjustment *hadjustment = gtk_tree_view_get_hadjustment (tree_view);
+	GtkWidget *button = column->button;
+
+	if ((hadjustment->value + hadjustment->page_size) <
+	    (button->allocation.x + button->allocation.width))
+		gtk_adjustment_set_value (hadjustment,
+					  button->allocation.x +
+					  button->allocation.width -
+					  hadjustment->page_size);
+	else if (hadjustment->value > button->allocation.x)
+		gtk_adjustment_set_value (hadjustment,
+					  button->allocation.x);
+}
+
 static void
 activate_column (StfDialogData *pagedata, int i)
 {
 	GOFormat *colformat;
 	GtkCellRenderer *cell;
+	GtkTreeViewColumn *column;
 	RenderData_t *renderdata = pagedata->format.renderdata;
 
 	cell = stf_preview_get_cell_renderer (renderdata,
@@ -103,8 +123,13 @@ activate_column (StfDialogData *pagedata, int i)
 	}
 
 	pagedata->format.index = i;
-	cell = stf_preview_get_cell_renderer (renderdata,
-					      pagedata->format.index);
+
+	column = stf_preview_get_column (renderdata, i);
+	if (column) {
+		tree_view_clamp_column_visible (renderdata->tree_view, column);
+	}
+
+	cell = stf_preview_get_cell_renderer (renderdata, i);
 	if (cell) {
 		g_object_set (G_OBJECT (cell),
 			      "background", "lightgrey",
@@ -133,8 +158,8 @@ cb_col_check_clicked (GtkToggleButton *togglebutton, gpointer _i)
 	StfDialogData *pagedata =
 		g_object_get_data (G_OBJECT (togglebutton), "pagedata");
 	gboolean active = gtk_toggle_button_get_active (togglebutton);
-	GtkCellRenderer   *renderer;
-	
+	GtkCellRenderer *renderer;
+
 	g_return_if_fail (i < pagedata->format.col_import_array_len);
 
 	if (pagedata->format.col_import_array[i] == active)
@@ -154,8 +179,10 @@ cb_col_check_clicked (GtkToggleButton *togglebutton, gpointer _i)
 			pagedata->format.col_import_count++;
 			format_page_update_column_selection (pagedata);
 		} else {
-			char *msg = g_strdup_printf 
-				(_("A maximum of %d columns can be imported."), 
+			char *msg = g_strdup_printf( 
+				ngettext("A maximum of %d column can be imported.",
+					 "A maximum of %d columns can be imported.",
+					 SHEET_MAX_COLS), 
 				 SHEET_MAX_COLS);
 			gtk_toggle_button_set_active (togglebutton, FALSE);
 			go_gtk_notice_dialog (GTK_WINDOW (pagedata->dialog),
@@ -230,7 +257,7 @@ cb_popup_menu_check_right (GtkWidget *widget, gpointer data)
 	StfDialogData *pagedata = data;
 	
 	check_columns_for_import (pagedata, pagedata->format.index + 1,
-				    pagedata->format.renderdata->colcount - 1);
+				  pagedata->format.renderdata->colcount - 1);
 }
 
 static void
@@ -378,6 +405,48 @@ cb_treeview_button_press (GtkWidget *treeview,
 	return FALSE;
 }
 
+static gint
+cb_treeview_key_press (GtkWidget *treeview,
+		       GdkEventKey *event,
+		       StfDialogData *pagedata)
+{
+	if (event->type == GDK_KEY_PRESS) {
+		switch (event->keyval) {
+		case GDK_Left:
+		case GDK_KP_Left:
+			if (pagedata->format.index > 0)
+				activate_column (pagedata,
+						 pagedata->format.index - 1);
+			return TRUE;
+
+		case GDK_Right:
+		case GDK_KP_Right:
+			if (pagedata->format.index + 1 < (int)pagedata->format.formats->len)
+				activate_column (pagedata,
+						 pagedata->format.index + 1);
+			return TRUE;
+
+		case GDK_space:
+		case GDK_Return: {
+			GtkTreeViewColumn *column = stf_preview_get_column
+				(pagedata->format.renderdata,
+				 pagedata->format.index);
+			GtkToggleButton *button =
+				g_object_get_data (G_OBJECT (column),
+						   "checkbox");
+			gtk_toggle_button_set_active
+				(button,
+				 !gtk_toggle_button_get_active (button));
+			return TRUE;
+		}
+
+		default:
+			; /*  Nothing.  */
+		}
+	}
+
+	return FALSE;
+}
 
 /**
  * format_page_update_preview
@@ -499,8 +568,7 @@ format_page_update_preview (StfDialogData *pagedata)
 					  GINT_TO_POINTER (i));
 		}
 	}
-	if (msg != NULL)
-		g_free (msg);
+	g_free (msg);
 }
 
 /*************************************************************************************************
@@ -547,7 +615,7 @@ cb_number_format_changed (G_GNUC_UNUSED GtkWidget *widget,
 					data->format.index);
 		go_format_unref (sf);
 
-		sf = go_format_new_from_XL (fmt, FALSE);
+		sf = go_format_new_from_XL (fmt);
 		gtk_label_set_text (GTK_LABEL (w), 
 				    go_format_sel_format_classification (sf));
 		g_ptr_array_index (data->format.formats, data->format.index) =
@@ -570,14 +638,14 @@ void
 stf_dialog_format_page_prepare (StfDialogData *data)
 {
 	GOFormat *sf;
+	GOFormat *general = go_format_general ();
 
 	/* Set the trim.  */
 	format_page_trim_menu_changed (NULL, data);
 
 	/* If necessary add new items (non-visual) */
 	while ((int)data->format.formats->len < data->format.renderdata->colcount)
-		g_ptr_array_add (data->format.formats,
-			go_format_new_from_XL (go_format_builtins[0][0], FALSE));
+		g_ptr_array_add (data->format.formats, go_format_ref (general));
 
 	data->format.manual_change = TRUE;
 	activate_column (data, 0);
@@ -635,6 +703,10 @@ stf_dialog_format_page_init (GladeXML *gui, StfDialogData *pagedata)
 
 	pagedata->format.locale_selector =
 		GO_LOCALE_SEL (go_locale_sel_new ());
+	if (pagedata->locale && !go_locale_sel_set_locale (pagedata->format.locale_selector, pagedata->locale)) {
+		g_free (pagedata->locale);
+		pagedata->locale = go_locale_sel_get_locale (pagedata->format.locale_selector);
+	}
 	gtk_table_attach (
 		GTK_TABLE (glade_xml_get_widget (gui, "locale_table")),
 		GTK_WIDGET (pagedata->format.locale_selector),
@@ -647,7 +719,7 @@ stf_dialog_format_page_init (GladeXML *gui, StfDialogData *pagedata)
 	/* Set properties */
 	pagedata->format.renderdata =
 		stf_preview_new (pagedata->format.format_data_container,
-				 workbook_date_conv (wb_control_workbook (WORKBOOK_CONTROL (pagedata->wbcg))));
+				 workbook_date_conv (wb_control_get_workbook (WORKBOOK_CONTROL (pagedata->wbcg))));
 	pagedata->format.formats          = g_ptr_array_new ();
 	pagedata->format.index         = -1;
 	pagedata->format.manual_change = FALSE;
@@ -673,4 +745,8 @@ stf_dialog_format_page_init (GladeXML *gui, StfDialogData *pagedata)
 			  "button_press_event",
 			  G_CALLBACK (cb_treeview_button_press),
 			  pagedata);
+	g_signal_connect (G_OBJECT (pagedata->format.renderdata->tree_view),
+			  "key_press_event",
+			  G_CALLBACK (cb_treeview_key_press),
+			  pagedata);
 }
