@@ -8,8 +8,8 @@
 #define GNM_CANVAS(o)	 (G_TYPE_CHECK_INSTANCE_CAST((o), GNM_CANVAS_TYPE, GnmCanvas))
 #define IS_GNM_CANVAS(o) (G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_CANVAS_TYPE))
 
-#define GNUMERIC_CANVAS_FACTOR_X 1000000*256
-#define GNUMERIC_CANVAS_FACTOR_Y 6000000*16
+#define GNUMERIC_CANVAS_FACTOR_X 1000000
+#define GNUMERIC_CANVAS_FACTOR_Y 6000000
 
 typedef struct {
 	int col, row;
