@@ -12,7 +12,7 @@
  *     ranges are highlighted on the spreadsheet).
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "item-edit.h"
 
@@ -41,6 +41,7 @@
 #include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
+#include <goffice/utils/go-font.h>
 
 static FooCanvasItemClass *parent_class;
 
@@ -95,14 +96,14 @@ static void
 ie_scan_for_range (ItemEdit *ie)
 {
 	GnmRange  range;
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (ie->scg));
+	Sheet *sheet = scg_sheet (ie->scg);
 	Sheet *parse_sheet;
 	GnmParsePos pp;
 	GnmExprEntry *gee = GNM_EXPR_ENTRY (
 		gtk_widget_get_parent (GTK_WIDGET (ie->entry)));
 
 	gnm_expr_entry_set_parsepos (gee,
-		parse_pos_init_editpos (&pp, sc_view (SHEET_CONTROL (ie->scg))));
+		parse_pos_init_editpos (&pp, scg_view (ie->scg)));
 	if (!ie->feedback_disabled) {
 		gnm_expr_expr_find_range (gee);
 		if (gnm_expr_entry_get_rangesel (gee, &range, &parse_sheet) &&
@@ -129,10 +130,8 @@ static void
 get_top_left (ItemEdit const *ie, int *top, int *left)
 {
 	GnmVAlign const align = gnm_style_get_align_v (ie->style);
-	ColRowInfo const *ci = sheet_col_get_info (
-		sc_sheet (SHEET_CONTROL (ie->scg)), ie->pos.col);
 
-	*left = ((int)ie->item.x1) + ci->margin_a;
+	*left = ((int)ie->item.x1) + GNM_COL_MARGIN;
 	*top  = (int)ie->item.y1;
 
 	if (align == VALIGN_CENTER || align == VALIGN_DISTRIBUTED ||
@@ -242,8 +241,8 @@ ie_layout (FooCanvasItem *item)
 	ItemEdit *ie = ITEM_EDIT (item);
 	GtkWidget const  *canvas = GTK_WIDGET (item->canvas);
 	GnmCanvas const  *gcanvas = GNM_CANVAS (item->canvas);
-	ColRowInfo const *cri;
-	Sheet	   const *sheet  = sc_sheet (SHEET_CONTROL (ie->scg));
+	ColRowInfo const *ci;
+	Sheet	   const *sheet  = scg_sheet (ie->scg);
 	GnmFont  const *gfont = ie->gfont;
 	GnmRange	   const *merged;
 	int end_col, end_row, tmp, width, height, col_size;
@@ -253,19 +252,19 @@ ie_layout (FooCanvasItem *item)
 	int cursor_pos = gtk_editable_get_position (GTK_EDITABLE (ie->entry));
 
 	end_col = ie->pos.col;
-	cri = sheet_col_get_info (sheet, end_col);
+	ci = sheet_col_get_info (sheet, end_col);
 
-	g_return_if_fail (cri != NULL);
+	g_return_if_fail (ci != NULL);
 
 	entered_text = gtk_entry_get_text (ie->entry);
-	text = wbcg_edit_get_display_text (scg_get_wbcg (ie->scg));
+	text = wbcg_edit_get_display_text (scg_wbcg (ie->scg));
 	pango_layout_set_text (ie->layout, text, -1);
 
-	pango_layout_set_font_description (ie->layout, gfont->pango.font_descr);
+	pango_layout_set_font_description (ie->layout, gfont->go.font->desc);
 	pango_layout_set_wrap (ie->layout, PANGO_WRAP_WORD_CHAR);
 	pango_layout_set_width (ie->layout, (int)(item->x2 - item->x1)*PANGO_SCALE);
 
-	attrs = wbcg_edit_get_markup (scg_get_wbcg (ie->scg), TRUE);
+	attrs = wbcg_edit_get_markup (scg_wbcg (ie->scg), TRUE);
 	if (attrs != NULL)
 		attrs = pango_attr_list_copy (attrs);
 	else
@@ -296,7 +295,7 @@ ie_layout (FooCanvasItem *item)
 	pango_layout_set_attributes (ie->layout, attrs);
 	pango_attr_list_unref (attrs);
 
-	text = wbcg_edit_get_display_text (scg_get_wbcg (ie->scg));
+	text = wbcg_edit_get_display_text (scg_wbcg (ie->scg));
 
 	if (gcanvas->preedit_length) {
 		PangoAttrList *tmp_attrs = pango_attr_list_new ();
@@ -311,29 +310,29 @@ ie_layout (FooCanvasItem *item)
 	pango_layout_get_pixel_size (ie->layout, &width, &height);
 
 	/* Start after the grid line and the left margin */
-	col_size = cri->size_pixels - cri->margin_a - 1;
+	col_size = ci->size_pixels - GNM_COL_MARGIN - 1;
 	if (sheet->text_is_rtl)
 		while (col_size < width &&
 		       end_col > gcanvas->first.col &&
 		       end_col > 0) {
 			end_col--;
-			cri = sheet_col_get_info (sheet, end_col);
-			g_return_if_fail (cri != NULL);
-			if (cri->visible)
-				col_size += cri->size_pixels;
+			ci = sheet_col_get_info (sheet, end_col);
+			g_return_if_fail (ci != NULL);
+			if (ci->visible)
+				col_size += ci->size_pixels;
 		}
 	else
-	while (col_size < width &&
-	       end_col <= gcanvas->last_full.col &&
-	       end_col < SHEET_MAX_COLS-1) {
-		end_col++;
-		cri = sheet_col_get_info (sheet, end_col);
-		g_return_if_fail (cri != NULL);
-		if (cri->visible)
-			col_size += cri->size_pixels;
-	}
+		while (col_size < width &&
+		       end_col <= gcanvas->last_full.col &&
+		       end_col < SHEET_MAX_COLS-1) {
+			end_col++;
+			ci = sheet_col_get_info (sheet, end_col);
+			g_return_if_fail (ci != NULL);
+			if (ci->visible)
+				col_size += ci->size_pixels;
+		}
 
-	merged = sheet_merge_is_corner (sheet, &ie->pos);
+	merged = gnm_sheet_merge_is_corner (sheet, &ie->pos);
 	if (merged != NULL) {
 		if (end_col < merged->end.col)
 			end_col = merged->end.col;
@@ -345,7 +344,7 @@ ie_layout (FooCanvasItem *item)
 	 * Recall that the bound excludes the far point */
 
 	if (sheet->text_is_rtl) {
-		tmp = gnm_simple_canvas_x_w2c (item->canvas, gcanvas->first_offset.col);
+		tmp = gnm_foo_canvas_x_w2c (item->canvas, gcanvas->first_offset.col);
 		item->x2 = 1 + item->x1 +
 			scg_colrow_distance_get (ie->scg, TRUE, end_col, ie->pos.col+1) - 2;
 	} else {
@@ -394,7 +393,7 @@ item_edit_realize (FooCanvasItem *item)
 
 	ie->layout = gtk_widget_create_pango_layout (GTK_WIDGET (item->canvas), NULL);
 	pango_layout_set_alignment (ie->layout,
-		ie->scg->sheet_control.sheet->text_is_rtl ? PANGO_ALIGN_RIGHT : PANGO_ALIGN_LEFT);
+		scg_sheet (ie->scg)->text_is_rtl ? PANGO_ALIGN_RIGHT : PANGO_ALIGN_LEFT);
 }
 
 static void
@@ -549,10 +548,10 @@ item_edit_set_property (GObject *gobject, guint param_id,
 
 	ie->scg = SHEET_CONTROL_GUI (g_value_get_object (value));
 
-	sv = sc_view (SHEET_CONTROL (ie->scg));
+	sv = scg_view (ie->scg);
 	ie->pos = sv->edit_pos;
-	ie->entry = entry = wbcg_get_entry (scg_get_wbcg (ie->scg));
-	g_signal_connect_object (G_OBJECT (scg_get_wbcg (ie->scg)),
+	ie->entry = entry = wbcg_get_entry (scg_wbcg (ie->scg));
+	g_signal_connect_object (G_OBJECT (scg_wbcg (ie->scg)),
 		"markup-changed",
 		G_CALLBACK (foo_canvas_item_request_update), G_OBJECT (ie), G_CONNECT_SWAPPED);
 	g_signal_connect_object (G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (entry))),
@@ -586,9 +585,9 @@ item_edit_set_property (GObject *gobject, guint param_id,
 		item->x1 = 1 + gcanvas->first_offset.col +
 			scg_colrow_distance_get (ie->scg, TRUE,
 				gcanvas->first.col, ie->pos.col);
-		if (ie->scg->sheet_control.sheet->text_is_rtl)
+		if (scg_sheet (ie->scg)->text_is_rtl)
 			/* -1 to remove the above, then 2 more to move from next cell back */
-			item->x1 = 2 + gnm_simple_canvas_x_w2c (item->canvas, item->x1 +
+			item->x1 = 2 + gnm_foo_canvas_x_w2c (item->canvas, item->x1 +
 				scg_colrow_distance_get (ie->scg, TRUE,
 					ie->pos.col, ie->pos.col + 1) - 1);
 
