@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef GNM_PRINT_INFO_H
 #define GNM_PRINT_INFO_H
 
@@ -5,17 +6,14 @@
 #include <gtk/gtk.h>
 
 typedef struct {
-	double    points;
-#if 0
-	GnomePrintUnit const *desired_display;
-#endif
-} PrintUnit;
+  GtkUnit   top, bottom, left, right, header, footer;
+} DesiredDisplay;
 
 /*
  * Margins.  In Points
  */
 typedef struct {
-	PrintUnit top, bottom;     /* see print.c for the definition (these are header/footer) */
+	double top, bottom;     /* see print.c for the definition (these are header/footer) */
 } PrintMargins;
 
 /* Header/Footer definition */
@@ -53,6 +51,7 @@ struct _PrintInformation {
 		} dim;
 	} scaling;
 	PrintMargins     margin;
+        DesiredDisplay   desired_display;
 	PrintRepeatRange repeat_top, repeat_left;
 	unsigned int	 print_across_then_down;
 	unsigned int     center_vertically:1;
@@ -61,10 +60,8 @@ struct _PrintInformation {
 	unsigned int     print_titles:1;	/* col/row headers */
 	unsigned int     print_black_and_white:1;
 	unsigned int     print_as_draft:1;
-	unsigned int     portrait_orientation:1;
 
 	/* Gnumeric specific */
-	unsigned int     invert_orientation:1;	/* gnome print offers R0 & R180 or R90 & R270 */
 	unsigned int     print_even_if_only_styles:1;
 
 	enum {
@@ -106,7 +103,7 @@ PrintInformation *print_info_dup	 (PrintInformation *pi);
 void              print_info_free        (PrintInformation *pi);
 void              print_info_save        (PrintInformation *pi);
 
-GtkPageSetup     *print_info_get_page_setup (PrintInformation const *pi);
+GtkPageSetup     *print_info_get_page_setup (PrintInformation *pi);
 void              print_info_set_page_setup (PrintInformation *pi, GtkPageSetup *page_setup);
 
 PrintHF          *print_hf_new           (char const *left,
@@ -123,12 +120,9 @@ char             *hf_format_render       (char const *format,
 HFRenderInfo     *hf_render_info_new     (void);
 void              hf_render_info_destroy (HFRenderInfo *hfi);
 
-#if 0
-GnomePrintUnit const *unit_name_to_unit    (char const *name);
-double      unit_convert             (double value,
-				      GnomePrintUnit const *source,
-				      GnomePrintUnit const *target);
-#endif
+
+GtkUnit     unit_name_to_unit    (char const *name);
+char const *unit_to_unit_name (GtkUnit unit);
 
 void        print_init               (void);
 void        print_shutdown           (void);
@@ -138,11 +132,16 @@ void        print_info_set_paper_width_height (PrintInformation *pi,
 					       double paper_width,
 					       double paper_height,
 					       GtkUnit unit);
+void	    print_info_set_paper_orientation   (PrintInformation *pi,
+						GtkPageOrientation orientation);
 char       *print_info_get_paper     	   (PrintInformation *pi);
 /* Note that the string returned by print_info_get_paper must be freed */
 
+char const *print_info_get_paper_display_name (PrintInformation *pi);
+
 double      print_info_get_paper_width     (PrintInformation *pi, GtkUnit unit);
 double      print_info_get_paper_height    (PrintInformation *pi, GtkUnit unit);
+GtkPageOrientation print_info_get_paper_orientation   (PrintInformation *pi);
 void        print_info_get_margins   (PrintInformation *pi,
 				      double *header, double *footer, double *left, double *right);
 void        print_info_set_margins   (PrintInformation *pi,
