@@ -54,10 +54,6 @@
 #include <goffice/app/go-cmd-context.h>
 #include <goffice/gtk/go-graph-widget.h>
 
-#ifdef WITH_GNOME_PRINT
-#include <goffice/graph/gog-renderer-gnome-print.h>
-#endif
-
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-output-stdio.h>
@@ -132,10 +128,10 @@ sog_data_set_sheet (G_GNUC_UNUSED SheetObjectGraph *sog,
 }
 
 static void
-sog_data_invalidate_sheet (G_GNUC_UNUSED SheetObjectGraph *sog,
-			   GOData *data, Sheet const *sheet)
+sog_data_foreach_dep (SheetObject *so, GOData *data,
+		      SheetObjectForeachDepFunc func, gpointer user)
 {
-	gnm_go_data_invalidate_sheet (data, sheet);
+	gnm_go_data_foreach_dep (data, so, func, user);
 }
 
 static void
@@ -215,11 +211,9 @@ gnm_sog_get_target_list (SheetObject const *so)
 static GtkTargetList *
 gnm_sog_get_object_target_list (SheetObject const *so)
 {
-	GtkTargetList *tl, *tl2;
-	GtkTargetPair *pair;
-	tl = gtk_target_list_new (NULL, 0);
-	gtk_target_list_add (tl, gdk_atom_intern
-					("application/x-goffice-graph", FALSE), 0, 0);
+	GtkTargetList *tl = gtk_target_list_new (NULL, 0);
+	gtk_target_list_add (tl,
+		gdk_atom_intern ("application/x-goffice-graph", FALSE), 0, 0);
 	return tl;
 }
 
@@ -391,16 +385,6 @@ gnm_sog_copy (SheetObject *dst, SheetObject const *src)
 	g_object_unref (graph);
 }
 
-#ifdef WITH_GNOME_PRINT
-static void
-gnm_sog_print (SheetObject const *so, GnomePrintContext *ctx,
-			  double width, double height)
-{
-	gog_graph_print_to_gnome_print (
-		SHEET_OBJECT_GRAPH (so)->graph, ctx, width, height);
-}
-#endif
-
 static void
 gnm_sog_draw_cairo (SheetObject const *so, gpointer data,
 			  double width, double height)
@@ -456,12 +440,14 @@ gnm_sog_user_config (SheetObject *so, SheetControl *sc)
 }
 
 static void
-gnm_sog_invalidate_sheet (SheetObject *so, Sheet const *sheet)
+gnm_sog_foreach_dep (SheetObject *so,
+		     SheetObjectForeachDepFunc func,
+		     gpointer user)
 {
 	SheetObjectGraph *sog = SHEET_OBJECT_GRAPH (so);
 	GSList *ptr = gog_graph_get_data (sog->graph);
 	for (; ptr != NULL ; ptr = ptr->next)
-		sog_data_invalidate_sheet (sog, ptr->data, sheet);
+		sog_data_foreach_dep (so, ptr->data, func, user);
 }
 
 static gboolean
@@ -524,15 +510,9 @@ gnm_sog_class_init (GObjectClass *klass)
 	so_class->user_config		= gnm_sog_user_config;
 	so_class->assign_to_sheet	= gnm_sog_set_sheet;
 	so_class->remove_from_sheet	= gnm_sog_remove_from_sheet;
-	so_class->print			= NULL;
-	
-#ifdef WITH_GNOME_PRINT
-	so_class->print			= gnm_sog_print;
-#endif
-
 	so_class->default_size		= gnm_sog_default_size;
 	so_class->draw_cairo		= gnm_sog_draw_cairo;
-	so_class->invalidate_sheet	= gnm_sog_invalidate_sheet;
+	so_class->foreach_dep		= gnm_sog_foreach_dep;
 
 	so_class->rubber_band_directly = FALSE;
 }
