@@ -34,7 +34,6 @@
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output-stdio.h>
 #include <string.h>
-#include <stdio.h>
 
 static gboolean ssindex_show_version = FALSE;
 static gboolean ssindex_list_mime_types = FALSE;
@@ -118,7 +117,7 @@ static void
 cb_index_styles (GnmStyle *style, gconstpointer dummy, IndexerState *state)
 {
 	if (gnm_style_is_element_set (style, MSTYLE_HLINK)) {
-		guchar const *str;
+		gchar const *str;
 		GnmHLink const *lnk = gnm_style_get_hlink (style);
 		if (lnk != NULL) {
 			if (NULL != (str = gnm_hlink_get_target (lnk)))
@@ -154,6 +153,7 @@ ssindex (char const *file, IOContext *ioc)
 	char	   *str = go_shell_arg_to_uri (file);
 	IndexerState state;
 	GsfOutput  *gsf_stdout;
+	Workbook   *wb;
 
 	state.wb_view = wb_view_new_from_uri (str, NULL,
 		ioc, ssindex_import_encoding);
@@ -165,9 +165,9 @@ ssindex (char const *file, IOContext *ioc)
 	gsf_stdout = gsf_output_stdio_new_FILE ("<stdout>", stdout, TRUE);
 	state.output = gsf_xml_out_new (gsf_stdout);
 	gsf_xml_out_start_element (state.output, "gnumeric");
-	state.wb = wb_view_get_workbook (state.wb_view);
-	for (i = 0 ; i < workbook_sheet_count (state.wb); i++) {
-		state.sheet = workbook_sheet_by_index (state.wb, i);
+	state.wb = wb = wb_view_get_workbook (state.wb_view);
+	for (i = 0 ; i < workbook_sheet_count (wb); i++) {
+		state.sheet = workbook_sheet_by_index (wb, i);
 		gsf_xml_out_simple_element (state.output,
 			"data", state.sheet->name_unquoted);
 
@@ -201,7 +201,7 @@ ssindex (char const *file, IOContext *ioc)
 	gsf_output_close (gsf_stdout);
 	g_object_unref (gsf_stdout);
 
-	g_object_unref ((gpointer)state.wb);
+	g_object_unref (wb);
 
 	return res;
 }
@@ -215,6 +215,8 @@ main (int argc, char **argv)
 	GOptionContext *ocontext;
 	GError *error = NULL;	
 
+	g_thread_init (NULL);
+
 	gnm_pre_parse_init (argv[0]);
 
 	ocontext = g_option_context_new (_("INFILE..."));
@@ -230,8 +232,8 @@ main (int argc, char **argv)
 	}
 
 	if (ssindex_show_version) {
-		g_print (_("ssindex version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
-			 GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
+		g_printerr (_("ssindex version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
+			    GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
 		return 0;
 	} else if (!ssindex_run_indexer && !ssindex_list_mime_types) {
 		g_printerr (_("Usage: %s [OPTION...] %s\n"),
@@ -256,7 +258,6 @@ main (int argc, char **argv)
 		for (i = 1; i < argc; i++) {
 			char const *file = argv[i];
 			gnm_io_context_processing_file (ioc, file);
-			g_print ("-> %s\n", file);
 			res |= ssindex (file, ioc);
 		}
 		g_object_unref (ioc);
