@@ -37,8 +37,8 @@
 #include "gnm-format.h"
 #include <gsf/gsf-output-iconv.h>
 #include <gsf/gsf-impl-utils.h>
+#include <goffice/utils/go-locale.h>
 
-#include <stdio.h>
 #include <string.h>
 #include <locale.h>
 
@@ -70,13 +70,13 @@ enum {
 /* ------------------------------------------------------------------------- */
 
 /**
- * stf_export_options_sheet_list_clear:
+ * gnm_stf_export_options_sheet_list_clear:
  * @stfe: an export options struct
  *
  * Clears the sheet list.
  **/
 void
-stf_export_options_sheet_list_clear (GnmStfExport *stfe)
+gnm_stf_export_options_sheet_list_clear (GnmStfExport *stfe)
 {
 	g_return_if_fail (stfe != NULL);
 
@@ -87,14 +87,14 @@ stf_export_options_sheet_list_clear (GnmStfExport *stfe)
 
 
 /**
- * stf_export_options_sheet_list_add:
+ * gnm_stf_export_options_sheet_list_add:
  * @stfe: an export options struct
  * @sheet: a gnumeric sheet
  *
  * Appends a @sheet to the list of sheets to be exported
  **/
 void
-stf_export_options_sheet_list_add (GnmStfExport *stfe, Sheet *sheet)
+gnm_stf_export_options_sheet_list_add (GnmStfExport *stfe, Sheet *sheet)
 {
 	g_return_if_fail (stfe != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
@@ -113,20 +113,27 @@ try_auto_date (GnmValue *value, const GOFormat *format,
 	GOFormat *actual;
 	char *res;
 	gboolean needs_date, needs_time, needs_frac_sec;
+	gboolean is_date, is_time;
 	GString *xlfmt;
 
+	is_date = gnm_format_is_date_for_value (format, value) > 0;
+	is_time = (go_format_get_family (format) == GO_FORMAT_TIME);
+
+	if (!is_date && !is_time)
+		return NULL;
+
 	if (!VALUE_IS_NUMBER (value))
 		return NULL;
 	v = value_get_as_float (value);
 	if (v >= 2958466)
 		return NULL;  /* Year 10000 or beyond.  */
-	if (v < -693594)
-		return NULL;  /* Before year 1 (whatever that is!)  */
+	if (v < 0)
+		return NULL;
 	vr = gnm_fake_round (v);
 	vs = (24 * 60 * 60) * gnm_abs (v - vr);
 
-	needs_date = (format->family == GO_FORMAT_DATE) || gnm_abs (v) >= 1;
-	needs_time = (format->family == GO_FORMAT_TIME) || gnm_abs (v - vr) > 1e-9;
+	needs_date = is_date || v >= 1;
+	needs_time = is_time || gnm_abs (v - vr) > 1e-9;
 	needs_frac_sec = needs_time && gnm_abs (vs - gnm_fake_trunc (vs)) > 1e-6;
 
 	xlfmt = g_string_new (NULL);
@@ -138,7 +145,7 @@ try_auto_date (GnmValue *value, const GOFormat *format,
 		if (needs_frac_sec)
 			g_string_append (xlfmt, ".000000");
 	}
-	actual = go_format_new_from_XL (xlfmt->str, FALSE);
+	actual = go_format_new_from_XL (xlfmt->str);
 	g_string_free (xlfmt, TRUE);
 	res = format_value (actual, value, NULL, -1, date_conv);
 	go_format_unref (actual);
@@ -164,17 +171,15 @@ stf_export_cell (GnmStfExport *stfe, GnmCell *cell)
 	if (cell) {
 		switch (stfe->format) {
 		case GNM_STF_FORMAT_PRESERVE:
-			text = tmp = cell_get_rendered_text (cell);
+			text = tmp = gnm_cell_get_rendered_text (cell);
 			break;
 		default:
 		case GNM_STF_FORMAT_AUTO:
 			if (cell->value) {
 				GODateConventions const *date_conv =
 					workbook_date_conv (cell->base.sheet->workbook);
-				GOFormat *format = cell_get_format (cell);
-				if (format->family == GO_FORMAT_DATE ||
-				    format->family == GO_FORMAT_TIME)
-					text = tmp = try_auto_date (cell->value, format, date_conv);
+				GOFormat *format = gnm_cell_get_format (cell);
+				text = tmp = try_auto_date (cell->value, format, date_conv);
 				if (!text)
 					text = value_peek_string (cell->value);
 			}
@@ -208,11 +213,26 @@ stf_export_sheet (GnmStfExport *stfe, Sheet *sheet)
 {
 	int col, row;
 	GnmRange r;
+	GnmRangeRef *range;
 
 	g_return_val_if_fail (stfe != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
-	r = sheet_get_extent (sheet, FALSE);
+	range = g_object_get_data (G_OBJECT (sheet->workbook), "ssconvert-range");
+	if (range) {
+		Sheet *start_sheet, *end_sheet;
+		GnmEvalPos ep;
+
+		gnm_rangeref_normalize (range,
+					eval_pos_init_sheet (&ep, sheet),
+					&start_sheet, &end_sheet,
+					&r);
+
+		if (start_sheet != sheet)
+			return TRUE;
+	} else
+		r = sheet_get_extent (sheet, FALSE);
+
 	for (row = r.start.row; row <= r.end.row; row++) {
 		for (col = r.start.col; col <= r.end.col; col++) {
 			GnmCell *cell = sheet_cell_get (sheet, col, row);
@@ -227,7 +247,7 @@ stf_export_sheet (GnmStfExport *stfe, Sheet *sheet)
 }
 
 /**
- * stf_export:
+ * gnm_stf_export:
  * @stfe: an export options struct
  *
  * Exports the sheets given in @stfe
@@ -235,14 +255,14 @@ stf_export_sheet (GnmStfExport *stfe, Sheet *sheet)
  * Return value: TRUE on success, FALSE otherwise
  **/
 gboolean
-stf_export (GnmStfExport *stfe)
+gnm_stf_export (GnmStfExport *stfe)
 {
 	GSList *ptr;
 	GsfOutput *sink;
 	gboolean result = TRUE;
 	char *old_locale = NULL;
 
-	g_return_val_if_fail (GNM_IS_STF_EXPORT (stfe), FALSE);
+	g_return_val_if_fail (IS_GNM_STF_EXPORT (stfe), FALSE);
 	g_return_val_if_fail (stfe->sheet_list != NULL, FALSE);
 	g_object_get (G_OBJECT (stfe), "sink", &sink, NULL);
 	g_return_val_if_fail (sink != NULL, FALSE);
@@ -280,11 +300,13 @@ stf_export (GnmStfExport *stfe)
 		go_setlocale (LC_ALL, stfe->locale);
 	}
 
-	for (ptr = stfe->sheet_list; ptr != NULL ; ptr = ptr->next)
-		if (!stf_export_sheet (stfe, ptr->data)) {
+	for (ptr = stfe->sheet_list; ptr != NULL ; ptr = ptr->next) {
+		Sheet *sheet = ptr->data;
+		if (!stf_export_sheet (stfe, sheet)) {
 			result = FALSE;
 			break;
 		}
+	}
 
 	if (stfe->locale) {
 		go_setlocale (LC_ALL, old_locale);
@@ -302,13 +324,13 @@ stf_export (GnmStfExport *stfe)
 /* ------------------------------------------------------------------------- */
 
 /**
- * stf_export_can_transliterate:
+ * gnm_stf_export_can_transliterate:
  *
  * Return value: TRUE iff //TRANSLIT is supported
  **/
 
 gboolean
-stf_export_can_transliterate (void)
+gnm_stf_export_can_transliterate (void)
 {
 	char const *text = "G\xc3\xbclzow";
 	char *encoded_text;
@@ -375,7 +397,7 @@ gnm_stf_export_finalize (GObject *obj)
 {
 	GnmStfExport *stfe = (GnmStfExport *)obj;
 
-	stf_export_options_sheet_list_clear (stfe);
+	gnm_stf_export_options_sheet_list_clear (stfe);
 	g_free (stfe->charset);
 	g_free (stfe->locale);
 
