@@ -25,14 +25,14 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "auto-correct.h"
 
-#include "dates.h"
 #include "application.h"
 #include "gutils.h"
 #include "gnumeric-gconf.h"
+#include <goffice/utils/go-format.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
