@@ -1,9 +1,9 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
- * wbc-gtk.c: A raw gtk based WorkbookControl
+ * wbc-gtk.c: A gtk based WorkbookControl
  *
- * Copyright (C) 2000-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
  * Copyright (C) 2006 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
@@ -44,6 +44,7 @@
 #include <goffice/gtk/go-action-combo-color.h>
 #include <goffice/gtk/go-action-combo-text.h>
 #include <goffice/gtk/go-action-combo-pixmaps.h>
+#include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-font.h>
 #include <goffice/utils/go-file.h>
@@ -91,6 +92,8 @@ struct _WBCgtk {
 
 	GtkWidget *menu_zone, *everything, *toolbar_zones[4];
 	GHashTable *custom_uis;
+
+	guint idle_update_style_feedback;
 };
 typedef WorkbookControlGUIClass WBCgtkClass;
 
@@ -234,59 +237,59 @@ static void
 cb_border_activated (GOActionComboPixmaps *a, WorkbookControl *wbc)
 {
 	Sheet *sheet = wb_control_cur_sheet (wbc);
-	GnmBorder *borders[STYLE_BORDER_EDGE_MAX];
+	GnmBorder *borders[GNM_STYLE_BORDER_EDGE_MAX];
 	int i;
 	int index = go_action_combo_pixmaps_get_selected (a, NULL);
 	
 	/* Init the list */
-	for (i = STYLE_BORDER_TOP; i < STYLE_BORDER_EDGE_MAX; i++)
+	for (i = GNM_STYLE_BORDER_TOP; i < GNM_STYLE_BORDER_EDGE_MAX; i++)
 		borders[i] = NULL;
 
 	switch (index) {
 	case 11 : /* left */
-		borders[STYLE_BORDER_LEFT] = style_border_fetch (STYLE_BORDER_THIN,
+		borders[GNM_STYLE_BORDER_LEFT] = gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 			 sheet_style_get_auto_pattern_color (sheet),
-			 style_border_get_orientation (STYLE_BORDER_LEFT));
+			 gnm_style_border_get_orientation (GNM_STYLE_BORDER_LEFT));
 		break;
 
 	case 12 : /* none */
-		for (i = STYLE_BORDER_TOP; i < STYLE_BORDER_EDGE_MAX; i++)
-			borders[i] = style_border_ref (style_border_none ());
+		for (i = GNM_STYLE_BORDER_TOP; i < GNM_STYLE_BORDER_EDGE_MAX; i++)
+			borders[i] = gnm_style_border_ref (gnm_style_border_none ());
 		break;
 
 	case 13 : /* right */
-		borders[STYLE_BORDER_RIGHT] = style_border_fetch (STYLE_BORDER_THIN,
+		borders[GNM_STYLE_BORDER_RIGHT] = gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 			 sheet_style_get_auto_pattern_color (sheet),
-			 style_border_get_orientation (STYLE_BORDER_RIGHT));
+			 gnm_style_border_get_orientation (GNM_STYLE_BORDER_RIGHT));
 		break;
 
 	case 21 : /* all */
-		for (i = STYLE_BORDER_HORIZ; i <= STYLE_BORDER_VERT; ++i)
-			borders[i] = style_border_fetch (STYLE_BORDER_THIN,
+		for (i = GNM_STYLE_BORDER_HORIZ; i <= GNM_STYLE_BORDER_VERT; ++i)
+			borders[i] = gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 				sheet_style_get_auto_pattern_color (sheet),
-				style_border_get_orientation (i));
+				gnm_style_border_get_orientation (i));
 		/* fall through */
 
 	case 22 : /* outside */
-		for (i = STYLE_BORDER_TOP; i <= STYLE_BORDER_RIGHT; ++i)
-			borders[i] = style_border_fetch (STYLE_BORDER_THIN,
+		for (i = GNM_STYLE_BORDER_TOP; i <= GNM_STYLE_BORDER_RIGHT; ++i)
+			borders[i] = gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 				sheet_style_get_auto_pattern_color (sheet),
-				style_border_get_orientation (i));
+				gnm_style_border_get_orientation (i));
 		break;
 
 	case 23 : /* thick_outside */
-		for (i = STYLE_BORDER_TOP; i <= STYLE_BORDER_RIGHT; ++i)
-			borders[i] = style_border_fetch (STYLE_BORDER_THICK,
+		for (i = GNM_STYLE_BORDER_TOP; i <= GNM_STYLE_BORDER_RIGHT; ++i)
+			borders[i] = gnm_style_border_fetch (GNM_STYLE_BORDER_THICK,
 				sheet_style_get_auto_pattern_color (sheet),
-				style_border_get_orientation (i));
+				gnm_style_border_get_orientation (i));
 		break;
 
 	case 41 : /* top_n_bottom */
 	case 42 : /* top_n_double_bottom */
 	case 43 : /* top_n_thick_bottom */
-		borders[STYLE_BORDER_TOP] = style_border_fetch (STYLE_BORDER_THIN,
+		borders[GNM_STYLE_BORDER_TOP] = gnm_style_border_fetch (GNM_STYLE_BORDER_THIN,
 			sheet_style_get_auto_pattern_color (sheet),
-			style_border_get_orientation (STYLE_BORDER_TOP));
+			gnm_style_border_get_orientation (GNM_STYLE_BORDER_TOP));
 	    /* Fall through */
 
 	case 31 : /* bottom */
@@ -294,14 +297,14 @@ cb_border_activated (GOActionComboPixmaps *a, WorkbookControl *wbc)
 	case 33 : /* thick_bottom */
 	{
 		int const tmp = index % 10;
-		StyleBorderType const t =
-		    (tmp == 1) ? STYLE_BORDER_THIN :
-		    (tmp == 2) ? STYLE_BORDER_DOUBLE
-		    : STYLE_BORDER_THICK;
+		GnmStyleBorderType const t =
+		    (tmp == 1) ? GNM_STYLE_BORDER_THIN :
+		    (tmp == 2) ? GNM_STYLE_BORDER_DOUBLE
+		    : GNM_STYLE_BORDER_THICK;
 
-		borders[STYLE_BORDER_BOTTOM] = style_border_fetch (t,
+		borders[GNM_STYLE_BORDER_BOTTOM] = gnm_style_border_fetch (t,
 			sheet_style_get_auto_pattern_color (sheet),
-			style_border_get_orientation (STYLE_BORDER_BOTTOM));
+			gnm_style_border_get_orientation (GNM_STYLE_BORDER_BOTTOM));
 		break;
 	}
 
@@ -707,11 +710,10 @@ cb_font_size_changed (GOActionComboText *a, WBCgtk *gtk)
 {
 	char const *new_size = go_action_combo_text_get_entry (gtk->font_size);
 	char *end;
-	float size;
+	double size;
 
-	errno = 0; /* strtol sets errno, but does not clear it.  */
-	size = strtod (new_size, &end);
-	size = ((int)floor ((size * 20.) + .5)) / 20.;	/* round .05 */
+	size = go_strtod (new_size, &end);
+	size = floor ((size * 20.) + .5) / 20.;	/* round .05 */
 
 	if (new_size != end && errno != ERANGE && 1. <= size && size <= 400.) {
 		if (wbcg_is_editing (WORKBOOK_CONTROL_GUI (gtk))) {
@@ -779,7 +781,7 @@ static void
 wbc_gtk_reload_recent_file_menu (WorkbookControlGUI const *wbcg)
 {
 	WBCgtk *gtk = (WBCgtk *)wbcg;
-	GSList const *ptr;
+	GSList *history, *ptr;
 	unsigned i;
 
 	if (gtk->file_history.merge_id != 0)
@@ -791,8 +793,8 @@ wbc_gtk_reload_recent_file_menu (WorkbookControlGUI const *wbcg)
 	gtk->file_history.actions = gtk_action_group_new ("FileHistory");
 
 	/* create the actions */
-	ptr = gnm_app_history_get_list (FALSE);
-	for (i = 1; ptr != NULL ; ptr = ptr->next, i++) {
+	history = gnm_app_history_get_list (FALSE);
+	for (i = 1, ptr = history; ptr != NULL ; ptr = ptr->next, i++) {
 		GtkActionEntry entry;
 		GtkAction *action;
 		char const *uri = ptr->data;
@@ -822,6 +824,8 @@ wbc_gtk_reload_recent_file_menu (WorkbookControlGUI const *wbcg)
 		g_free (tooltip);		
 	}
 
+	go_slist_free_custom (history, (GFreeFunc)g_free);
+
 	gtk_ui_manager_insert_action_group (gtk->ui, gtk->file_history.actions, 0);
 
 	/* merge them in */
@@ -951,7 +955,7 @@ wbc_gtk_init_state (WorkbookControl *wbc)
 }
 
 static void
-wbc_gtk_style_feedback (WorkbookControl *wbc, GnmStyle const *changes)
+wbc_gtk_style_feedback_real (WorkbookControl *wbc, GnmStyle const *changes)
 {
 	WorkbookView	*wb_view = wb_control_view (wbc);
 	WBCgtk		*wbcg = (WBCgtk *)wbc;
@@ -962,7 +966,7 @@ wbc_gtk_style_feedback (WorkbookControl *wbc, GnmStyle const *changes)
 		return;
 
 	if (changes == NULL)
-		changes = wb_view->current_format;
+		changes = wb_view->current_style;
 
 	if (gnm_style_is_element_set (changes, MSTYLE_FONT_BOLD))
 		gtk_toggle_action_set_active (wbcg->font.bold,
@@ -1024,6 +1028,25 @@ wbc_gtk_style_feedback (WorkbookControl *wbc, GnmStyle const *changes)
 	wbcg_ui_update_end (WORKBOOK_CONTROL_GUI (wbc));
 }
 
+static gint
+cb_wbc_gtk_style_feedback (WBCgtk *gtk)
+{
+	wbc_gtk_style_feedback_real ((WorkbookControl *)gtk, NULL);
+	gtk->idle_update_style_feedback = 0;
+	return FALSE;
+}
+static void
+wbc_gtk_style_feedback (WorkbookControl *wbc, GnmStyle const *changes)
+{
+	WBCgtk *wbcg = (WBCgtk *)wbc;
+
+	if (changes)
+		wbc_gtk_style_feedback_real (wbc, changes);
+	else if (0 == wbcg->idle_update_style_feedback)
+		wbcg->idle_update_style_feedback = g_timeout_add (400,
+			(GSourceFunc) cb_wbc_gtk_style_feedback, wbc);
+}
+
 extern void wbcg_register_actions (WorkbookControlGUI *wbcg,
 				   GtkActionGroup *menu_group,
 				   GtkActionGroup *group,
@@ -1675,6 +1698,8 @@ wbc_gtk_init (GObject *obj)
 	gtk->toolbar_zones[GTK_POS_LEFT] = gtk_hbox_new (FALSE, 0);
 	gtk->toolbar_zones[GTK_POS_RIGHT] = gtk_hbox_new (FALSE, 0);
 
+	gtk->idle_update_style_feedback = 0;
+
 #ifdef USE_HILDON
 	if (hildon_program == NULL)
 		hildon_program = HILDON_PROGRAM (hildon_program_get_instance ());
@@ -1828,6 +1853,8 @@ wbc_gtk_finalize (GObject *obj)
 {
 	WBCgtk *gtk = (WBCgtk *)obj;
 
+	if (gtk->idle_update_style_feedback != 0)
+		g_source_remove (gtk->idle_update_style_feedback);
 	if (gtk->file_history.merge_id != 0)
 		gtk_ui_manager_remove_ui (gtk->ui, gtk->file_history.merge_id);
 	if (gtk->file_history.actions != NULL)
@@ -1843,6 +1870,234 @@ wbc_gtk_finalize (GObject *obj)
 	parent_class->finalize (obj);
 }
 
+static void
+wbc_gtk_setup_pixmaps (void)
+{
+	static struct {
+		guchar const   *scalable_data;
+		gchar const    *name;
+	} const entry [] = {
+		/* Cursors */
+		{ gnm_cursor_cross, "cursor_cross" },
+		{ gnm_bucket, "bucket" },
+		{ gnm_font, "font" },
+		{ sheet_move_marker, "sheet_move_marker" },
+		/* Patterns */
+		{ gp_125grey, "gp_125grey" },
+		{ gp_25grey, "gp_25grey" },
+		{ gp_50grey, "gp_50grey" },
+		{ gp_625grey, "gp_625grey" },
+		{ gp_75grey, "gp_75grey" },
+		{ gp_bricks, "gp_bricks" },
+		{ gp_diag, "gp_diag" },
+		{ gp_diag_cross, "gp_diag_cross" },
+		{ gp_foreground_solid, "gp_foreground_solid" },
+		{ gp_horiz, "gp_horiz" },
+		{ gp_large_circles, "gp_large_circles" },
+		{ gp_rev_diag, "gp_rev_diag" },
+		{ gp_semi_circle, "gp_semi_circle" },
+		{ gp_small_circle, "gp_small_circle" },
+		{ gp_solid, "gp_solid" },
+		{ gp_thatch, "gp_thatch" },
+		{ gp_thick_diag_cross, "gp_thick_diag_cross" },
+		{ gp_thin_diag, "gp_thin_diag" },
+		{ gp_thin_diag_cross, "gp_thin_diag_cross" },
+		{ gp_thin_horiz, "gp_thin_horiz" },
+		{ gp_thin_horiz_cross, "gp_thin_horiz_cross" },
+		{ gp_thin_rev_diag, "gp_thin_rev_diag" },
+		{ gp_thin_vert, "gp_thin_vert" },
+		{ gp_vert, "gp_vert" },
+		{ line_pattern_dash_dot, "line_pattern_dash_dot" },
+		{ line_pattern_dash_dot_dot, "line_pattern_dash_dot_dot" },
+		{ line_pattern_dashed, "line_pattern_dashed" },
+		{ line_pattern_dotted, "line_pattern_dotted" },
+		{ line_pattern_double, "line_pattern_double" },
+		{ line_pattern_hair, "line_pattern_hair" },
+		{ line_pattern_medium, "line_pattern_medium" },
+		{ line_pattern_medium_dash, "line_pattern_medium_dash" },
+		{ line_pattern_medium_dash_dot, "line_pattern_medium_dash_dot" },
+		{ line_pattern_medium_dash_dot_dot, "line_pattern_medium_dash_dot_dot" },
+		{ line_pattern_slant, "line_pattern_slant" },
+		{ line_pattern_thick, "line_pattern_thick" },
+		{ line_pattern_thin, "line_pattern_thin" },
+		/* Borders */
+		{ bottom_border, "bottom_border" },
+		{ diag_border, "diag_border" },
+		{ inside_border, "inside_border" },
+		{ inside_horiz_border, "inside_horiz_border" },
+		{ inside_vert_border, "inside_vert_border" },
+		{ left_border, "left_border" },
+		{ no_border, "no_border" },
+		{ outline_border, "outline_border" },
+		{ rev_diag_border, "rev_diag_border" },
+		{ right_border, "right_border" },
+		{ top_border, "top_border" },
+		/* Stuff */
+		{ unknown_image, "unknown_image" }
+	};
+	unsigned int ui;
+
+	for (ui = 0; ui < G_N_ELEMENTS (entry); ui++) {
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline
+			(-1, entry[ui].scalable_data, FALSE, NULL);
+		gtk_icon_theme_add_builtin_icon (entry[ui].name,
+			gdk_pixbuf_get_width (pixbuf), pixbuf);
+		g_object_unref (pixbuf);
+	}
+}
+
+static void
+add_icon (GtkIconFactory *factory,
+	  guchar const   *scalable_data,
+	  guchar const   *sized_data,
+	  gchar const    *stock_id)
+{
+	GtkIconSet *set = gtk_icon_set_new ();
+	GtkIconSource *src = gtk_icon_source_new ();
+
+	if (scalable_data != NULL) {
+		gtk_icon_source_set_size_wildcarded (src, TRUE);
+		gtk_icon_source_set_pixbuf (src,
+			gdk_pixbuf_new_from_inline (-1, scalable_data, FALSE, NULL));
+		gtk_icon_set_add_source (set, src);	/* copies the src */
+	}
+
+	/*
+	 * For now, don't register a fixed-sized icon as doing so without
+	 * catching style changes kills things like bug 302902.
+	 */
+	if (scalable_data == NULL && sized_data != NULL) {
+		gtk_icon_source_set_size (src, GTK_ICON_SIZE_MENU);
+		gtk_icon_source_set_size_wildcarded (src, FALSE);
+		gtk_icon_source_set_pixbuf (src,
+			gdk_pixbuf_new_from_inline (-1, sized_data, FALSE, NULL));
+		gtk_icon_set_add_source (set, src);	/* copies the src */
+	}
+
+	gtk_icon_factory_add (factory, stock_id, set);	/* keeps reference to set */
+	gtk_icon_set_unref (set);
+	gtk_icon_source_free (src);
+}
+
+static void
+wbc_gtk_setup_icons (void)
+{
+	static struct {
+		guchar const   *scalable_data;
+		guchar const   *sized_data;
+		gchar const    *stock_id;
+	} const entry [] = {
+		{ gnm_column_add_24,			gnm_column_add_16,		"Gnumeric_ColumnAdd" },
+		{ gnm_column_delete_24,			gnm_column_delete_16,		"Gnumeric_ColumnDelete" },
+		{ gnm_column_size_24,			gnm_column_size_16,		"Gnumeric_ColumnSize" },
+		{ gnm_column_hide_24,			gnm_column_hide_16,		"Gnumeric_ColumnHide" },
+		{ gnm_column_unhide_24,			gnm_column_unhide_16,		"Gnumeric_ColumnUnhide" },
+		{ gnm_row_add_24,			gnm_row_add_16,			"Gnumeric_RowAdd" },
+		{ gnm_row_delete_24,			gnm_row_delete_16,		"Gnumeric_RowDelete" },
+		{ gnm_row_size_24,			gnm_row_size_16,		"Gnumeric_RowSize" },
+		{ gnm_row_hide_24,			gnm_row_hide_16,		"Gnumeric_RowHide" },
+		{ gnm_row_unhide_24,			gnm_row_unhide_16,		"Gnumeric_RowUnhide" },
+
+		{ gnm_group_24,				gnm_group_16,			"Gnumeric_Group" },
+		{ gnm_ungroup_24,			gnm_ungroup_16,			"Gnumeric_Ungroup" },
+		{ gnm_show_detail_24,			gnm_show_detail_16,		"Gnumeric_ShowDetail" },
+		{ gnm_hide_detail_24,			gnm_hide_detail_16,		"Gnumeric_HideDetail" },
+
+		{ gnm_graph_guru_24,			gnm_graph_guru_16,		"Gnumeric_GraphGuru" },
+		{ gnm_insert_component_24,		gnm_insert_component_16,	"Gnumeric_InsertComponent" },
+		{ gnm_insert_shaped_component_24,	gnm_insert_shaped_component_16,	"Gnumeric_InsertShapedComponent" },
+
+		{ gnm_center_across_selection_24,	gnm_center_across_selection_16,	"Gnumeric_CenterAcrossSelection" },
+		{ gnm_merge_cells_24,			gnm_merge_cells_16,		"Gnumeric_MergeCells" },
+		{ gnm_split_cells_24,			gnm_split_cells_16,		"Gnumeric_SplitCells" },
+
+		{ gnm_halign_fill_24,			NULL,				"Gnumeric_HAlignFill" },
+		{ gnm_halign_general_24,		NULL,				"Gnumeric_HAlignGeneral" },
+
+		{ NULL,					gnm_comment_add_16,		"Gnumeric_CommentAdd" },
+		{ NULL,					gnm_comment_delete_16,		"Gnumeric_CommentDelete" },
+		{ NULL,					gnm_comment_edit_16,		"Gnumeric_CommentEdit" },
+
+		{ gnm_add_decimals,			NULL,				"Gnumeric_FormatAddPrecision" },
+		{ gnm_remove_decimals,			NULL,				"Gnumeric_FormatRemovePrecision" },
+		{ gnm_money,				NULL,				"Gnumeric_FormatAsAccounting" },
+		{ gnm_percent,				NULL,				"Gnumeric_FormatAsPercentage" },
+		{ gnm_thousand,				NULL,				"Gnumeric_FormatThousandSeparator" },
+
+		{ gnm_auto,				NULL,				"Gnumeric_AutoSum" },
+		{ gnm_equal,				NULL,				"Gnumeric_Equal" },
+		{ gnm_formula_guru_24,			gnm_formula_guru_16,		"Gnumeric_FormulaGuru" },
+		{ gnm_insert_image_24,			gnm_insert_image_16,		"Gnumeric_InsertImage" },
+		{ gnm_bucket,				NULL,				"Gnumeric_Bucket" },
+		{ gnm_font,				NULL,				"Gnumeric_Font" },
+		{ gnm_expr_entry,			NULL,				"Gnumeric_ExprEntry" },
+		{ gnm_brush_22,				gnm_brush_16,			"Gnumeric_Brush" },
+
+		{ gnm_object_arrow_24,			NULL,				"Gnumeric_ObjectArrow" },
+		{ gnm_object_ellipse_24,		NULL,				"Gnumeric_ObjectEllipse" },
+		{ gnm_object_line_24,			NULL,				"Gnumeric_ObjectLine" },
+		{ gnm_object_rectangle_24,		NULL,				"Gnumeric_ObjectRectangle" },
+
+		{ gnm_object_frame_24,			NULL,				"Gnumeric_ObjectFrame" },
+		{ gnm_object_label_24,			NULL,				"Gnumeric_ObjectLabel" },
+		{ gnm_object_button_24,			NULL,				"Gnumeric_ObjectButton" },
+		{ gnm_object_checkbox_24,		NULL,				"Gnumeric_ObjectCheckbox" },
+		{ gnm_object_radiobutton_24,		NULL,				"Gnumeric_ObjectRadioButton" },
+		{ gnm_object_scrollbar_24,		NULL,				"Gnumeric_ObjectScrollbar" },
+		{ gnm_object_spinbutton_24,		NULL,				"Gnumeric_ObjectSpinButton" },
+		{ gnm_object_slider_24,			NULL,				"Gnumeric_ObjectSlider" },
+		{ gnm_object_combo_24,			NULL,				"Gnumeric_ObjectCombo" },
+		{ gnm_object_list_24,			NULL,				"Gnumeric_ObjectList" },
+
+		{ gnm_pivottable_24,	                gnm_pivottable_16,		"Gnumeric_PivotTable" },
+		{ gnm_protection_yes,	                NULL,				"Gnumeric_Protection_Yes" },
+		{ gnm_protection_no,       		NULL,				"Gnumeric_Protection_No" },
+		{ gnm_protection_yes_48,	        NULL,				"Gnumeric_Protection_Yes_Dialog" },
+		{ gnm_visible,	                        NULL,				"Gnumeric_Visible" },
+
+		{ gnm_link_add_24,			gnm_link_add_16,		"Gnumeric_Link_Add" },
+		{ NULL,					gnm_link_delete_16,		"Gnumeric_Link_Delete" },
+		{ NULL,					gnm_link_edit_16,		"Gnumeric_Link_Edit" },
+		{ gnm_link_external_24,			gnm_link_external_16,		"Gnumeric_Link_External" },
+		{ gnm_link_internal_24,			gnm_link_internal_16,		"Gnumeric_Link_Internal" },
+		{ gnm_link_email_24,			gnm_link_email_16,		"Gnumeric_Link_EMail" },
+		{ gnm_link_url_24,			gnm_link_url_16,		"Gnumeric_Link_URL" },
+
+		{ gnm_autofilter_24,			gnm_autofilter_16,		"Gnumeric_AutoFilter" },
+		{ gnm_autofilter_delete_24,		gnm_autofilter_delete_16,	"Gnumeric_AutoFilterDelete" },
+
+		{ gnm_border_left,			NULL,				"Gnumeric_BorderLeft" },
+		{ gnm_border_none,			NULL,				"Gnumeric_BorderNone" },
+		{ gnm_border_right,			NULL,				"Gnumeric_BorderRight" },
+
+		{ gnm_border_all,			NULL,				"Gnumeric_BorderAll" },
+		{ gnm_border_outside,			NULL,				"Gnumeric_BorderOutside" },
+		{ gnm_border_thick_outside,		NULL,				"Gnumeric_BorderThickOutside" },
+
+		{ gnm_border_bottom,			NULL,				"Gnumeric_BorderBottom" },
+		{ gnm_border_double_bottom,		NULL,				"Gnumeric_BorderDoubleBottom" },
+		{ gnm_border_thick_bottom,		NULL,				"Gnumeric_BorderThickBottom" },
+
+		{ gnm_border_top_n_bottom,		NULL,				"Gnumeric_BorderTop_n_Bottom" },
+		{ gnm_border_top_n_double_bottom,	NULL,				"Gnumeric_BorderTop_n_DoubleBottom" },
+		{ gnm_border_top_n_thick_bottom,	NULL,				"Gnumeric_BorderTop_n_ThickBottom" }
+	};
+	static gboolean done = FALSE;
+
+	if (!done) {
+		unsigned int ui = 0;
+		GtkIconFactory *factory = gtk_icon_factory_new ();
+		for (ui = 0; ui < G_N_ELEMENTS (entry) ; ui++)
+			add_icon (factory,
+				  entry[ui].scalable_data,
+				  entry[ui].sized_data,
+				  entry[ui].stock_id);
+		gtk_icon_factory_add_default (factory);
+		g_object_unref (G_OBJECT (factory));
+		done = TRUE;
+	}
+}
+
 static void
 wbc_gtk_class_init (GObjectClass *object_class)
 {
@@ -1869,6 +2124,9 @@ wbc_gtk_class_init (GObjectClass *object_class)
 	wbcg_class->set_toggle_action_state	= wbc_gtk_set_toggle_action_state;
 
 	object_class->finalize = wbc_gtk_finalize;
+
+	wbc_gtk_setup_pixmaps ();
+	wbc_gtk_setup_icons ();
 }
 
 GSF_CLASS (WBCgtk, wbc_gtk,
